Trait Array

pub unsafe trait Array {
    type Item;

    // Required method
    fn size() -> usize;
}
Available on crate feature wayland and Linux only.
Types that can be used as the backing store for a SmallVec.

Required Associated Types

type Item

The type of the array’s elements.

Required Methods

fn size() -> usize

Returns the number of items the array can hold.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementations on Foreign Types



impl<T, const N: usize> Array for [T; N]



type Item = T



fn size() -> usize

Implementors